@@ -23,9 +23,7 @@ file_trajectory = read.read_parameters(input_file)[9]
 file_initial_conf = read.read_parameters(input_file)[10]
 system = read.read_parameters(input_file)[11]
 DT = read.read_parameters(input_file)[12]
-tau = read.read_parameters(input_file)[13]
-T = read.read_parameters(input_file)[14]
-windowing = read.read_parameters(input_file)[15]
+
 
 
 tot_atoms_uc = int(np.sum(n_atom_unit_cell)) 
@@ -46,8 +44,6 @@ print(' Masses: ', Masses)
 print(' Number of atoms per unit cell', n_atom_unit_cell)
 print(' Supercell: ', N1, N2, N3)
 print(' k path: ', [x.tolist() for x in kinput])
-print(' Temperature: ', T, ' K')
-print(' Number of timesteps chosen for correlation function: ', tau)
 print(' Extent of timestep [ps]: ', DT*2.418884254*1e-05)
 print()
 print('Now calculating velocities...')
@@ -57,32 +53,38 @@ Ruc, R0 = read.read_SPOSCAR(file_initial_conf, N1N2N3, N, n_atom_conventional_ce
 
 Rt = np.loadtxt(file_trajectory)[:,1:]
 Num_timesteps = int(len(Rt[:,0]))
-print(' Number of timesteps of simulation: ', Num_timesteps, '\n')
+print(' Number of timesteps of simulation: ', Num_timesteps)
 tall = np.arange(Num_timesteps)*DT*2.418884254*1e-05 #conversion to picoseconds
 dt_ps = tall[1]-tall[0]
 Vt = np.diff(Rt,axis=0)/dt_ps*np.sqrt(masses)/np.sqrt(3*(N))
+T = np.sum(np.average(Vt**2*cev/kbev, axis=0))
+print(' Temperature: ',T, ' K')
 
-
-meta = util.max_freq(dt_ps, tau) #you want the max frequency plotted be 25 Thz
+meta = util.max_freq(dt_ps, Num_timesteps) #you want the max frequency plotted be 25 Thz
 ZS, Zqs = np.zeros((meta,1+Nqpoints+1)), np.zeros((meta,tot_atoms_uc*3+1))
 
 
-#this is for the total C(t)
-t_tot, C_tot, freq_tot, G_tot = util.corr(tall,Vt,Vt,tau, ' ')
-Z_tot = np.sqrt(np.conjugate(G_tot)*G_tot).real*cev/(kbev*T)
-print(' Total spectrum, average total kinetic energy per dof: ', 1/2*C_tot[0]*cH, ' Hartree')
-print(' Kinetic energy per dof according to eqp thm: ', 1/2*kbH*T, ' Hartree')
-print('\t\t ratio: ', np.round((1/2*C_tot[0]*cH)/(1/2*kbH*T)*100,2), ' %\n')
-ZS[:,0], ZS[:,1] = freq_tot[0:meta], Z_tot[0:meta]
+Vw, freq = np.fft.fft(Vt, axis=0), np.fft.fftfreq(Num_timesteps-1, dt_ps)
+S = np.sum(np.conjugate(Vw)*Vw, axis=1).real*cev/(kbev*T)/Num_timesteps*dt_ps
+tot_area = np.trapz(S,freq)
+print(' The total DOS is ', tot_area*N)
+print(' You are losing ',N - tot_area*N, ' kBT')
+ZS[:,0] = freq[0:meta]
+
+Ctot = np.fft.ifft(S)
+for t in range(int(len(Ctot)/2)):
+    Ctot[t] = Ctot[t]*Num_timesteps/(Num_timesteps-t)
+C = Ctot[0:int(len(Ctot)/2)].real
 
 
-print('Done. Performing decomposition...\n')
 
+print('\nDone. Performing decomposition...\n')
 #anis = list(range(tot_atoms_uc*3))
 #namedir = plot.create_folder(system)
 #every_tot = int(tot_atoms_conventional_cell/tot_atoms_uc)
 for i in range(Nqpoints):
     eigvec = eigvecs[i]
+    eigvecH = np.conjugate(eigvec.T)
     freq_disp = freqs[i]
     k = ks[i]
     k_scal = qpoints_scaled[i]
@@ -90,39 +92,30 @@ for i in range(Nqpoints):
     print('\t kpoint:        ',np.round(k,3))
     
     #Creating the collective variable based on the k point
-    Vcoll = np.zeros((Num_timesteps-1,tot_atoms_uc*3),dtype=complex)  
-    for j,h,l in zip(range(tot_atoms_uc*3),np.repeat(range(0,N),3)*N1N2N3*3,np.tile(range(0,3),tot_atoms_uc)):
-        vels = np.array(Vt[:,h+l:h+N1N2N3*3:3],dtype=complex)
-        poss = R0[h:h+N1N2N3*3:3,:]
-        x = np.multiply(vels,np.exp(-1j*np.dot(poss,k)))
-        Vcoll[:,j] = np.sum(x,axis=1)
-    Tkt = Vcoll  
+    Tkt = util.create_Tkt(Num_timesteps-1, tot_atoms_uc, N1N2N3, Vt, R0, k)
+    Qkt = np.dot(eigvecH,Tkt.T).T
     
 ##   this was to convert conventional into primitive
 #    Tkt = np.zeros((Num_timesteps-1,tot_atoms_uc*3), dtype=complex)
 #    for l,m in zip(range(0,tot_atoms_conventional_cell*3, every_tot*3),range(0,tot_atoms_uc*3,3)):
 #        Tkt[:,m:m+3] = Vcoll[:,l:l+3]
-    eigvecH = np.conjugate(eigvec.T)
-    Qkt = np.dot(eigvecH,Tkt.T).T
+    
+    Tkw = np.fft.fft(Tkt, axis=0)
+    Sq = (np.sum(np.conjugate(Tkw)*Tkw, axis=1)).real*cev/(kbev*T)/Num_timesteps*dt_ps
+    area_q = np.trapz(Sq, freq)
+    print('\t DOS for this kpoint: ', area_q)
     
     
-    t, C, freq, G = util.corr(tall,Tkt,Tkt,tau, ' ')
-    Z_q = np.sqrt(np.conjugate(G)*G).real*cev/(kbev*T)
-    print('\t  kinetic energy of this kpoint: ',1/2*C.real[0]*cH, ' Hartree')
-    print('\t  kinetic according to eqp thm: ',1/2*kbH*T, ' Hartree')
-    print('\t  ratio: ', np.round((1/2*C.real[0]*cH)/(1/2*kbH*T)*100,2), ' %')
-    ZS[:,i+2] = Z_q[0:meta]
-        
-    
-    t_proj, C_proj, freq_proj, G_proj = util.corr(tall,Qkt,Qkt,tau, 'projected')
-    Z = np.sqrt(np.conjugate(G_proj)*G_proj).real*cev/(kbev*T)
-    
-    Zqs[:,0] = Z_q[0:meta]
-    Zqs[:,1:] = Z[0:meta,:]
+    Qkw = np.fft.fft(Qkt, axis=0)
+    Sq_proj = (np.conjugate(Qkw)*Qkw).real*cev/(kbev*T)/Num_timesteps*dt_ps
+
+
+    Zqs[:,0] = Sq[0:meta]
+    Zqs[:,1:] = Sq_proj[0:meta,:]
     
     Params = np.zeros((3,tot_atoms_uc*3))
     for n in range(tot_atoms_uc*3):
-        x_data, y_data = freq[0:meta], Z[0:meta,n]
+        x_data, y_data = freq[0:int(Num_timesteps/2)], Sq_proj[0:int(Num_timesteps/2),n]
         popt, perr = util.fit_to_lorentzian(x_data, y_data, k, n)
         print()
         print('\t\tFitting to Lorentzian, mode '+str(n)+'...')
@@ -132,13 +125,13 @@ for i in range(Nqpoints):
         Params[:,n] = popt
 
 #        anis[n] = plot.plot_with_ani(freq[0:meta],Z[0:meta,n],Z_q[0:meta], k, eigvec[:,n],freq_disp[n],n,Ruc,file_eigenvectors,masses_for_animation)
-#        plot.save_proj(freq[0:meta],Z[0:meta,n],Z_q[0:meta], qpoints_scaled[i], Ruc, eigvec[:,n],freq_disp[n],n,namedir,masses_for_animation, popt, -1)  
+#        plot.save_proj(ff[0:meta*2],Sq_proj[0:meta*2,n],Sq[0:meta*2], qpoints_scaled[i], Ruc, eigvec[:,n],freq_disp[n],n,namedir,masses_for_animation, popt, -1)  
    
     util.save_append('Zqs', k_scal.reshape(1,3), Zqs)
     util.save_append('quasiparticles', k_scal.reshape(1,3), Params)  
     print()
 
 
-util.save('C(t)', np.vstack((t_tot,C_tot)).T)
+util.save('C_t', np.vstack((tall[0:len(C)],C)).T)
 util.save('ZS', ZS)
     
