@@ -26,7 +26,6 @@ def figsize(scale):
 #warnings.filterwarnings('ignore') 
 import matplotlib as mpl
 mpl.use('pgf')
-
 import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d import Axes3D
 from matplotlib import animation
@@ -163,7 +162,7 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
 
     "axes.labelsize": 16,                # LaTeX default is 10pt font.     "text.fontsize": 10,
 
-    "legend.fontsize": 12,               # Make the legend/label fonts a little smaller
+    "legend.fontsize": 'x-small',               # Make the legend/label fonts a little smaller
 
     "xtick.labelsize": 16,
 
@@ -191,7 +190,8 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
     plt.ioff()
     fig,ax = plt.subplots()
     #graph2, = ax.plot(x,ytot,'--',label='k-point DOS', color='grey')
-    graph1, = ax.plot(x,y,label='mode-projected DOS', color='blue', alpha=0.7)
+    graph1, = ax.plot(x,y,label='mode-projected DOS', color='blue', alpha=0.7, linewidth=.5)
+
     ax.set_xlabel('Frequency [Thz]')
     ax.set_ylabel('DOS [kB T * ps]')
 #    fig.suptitle('Spectrum of mode n. '+str(n)+' kpoint '+str(k))
@@ -235,7 +235,7 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
     
       
     graph3, = ax.plot(np.repeat(freq,100),np.linspace(0,y.max(),100), c='red', label='freq from dispersion')
-    plt.legend(handles=[graph1, graph3])
+    plt.legend(handles=[graph1, graph3, graph4])
     
 #    plt.subplots_adjust(top=0.85)
 #    if(np.allclose(k,[0,0,0])):
@@ -392,7 +392,7 @@ def plot1(freq,ZQS, labels):
 
     "axes.labelsize": 16,                # LaTeX default is 10pt font.     "text.fontsize": 10,
 
-    "legend.fontsize": 12,               # Make the legend/label fonts a little smaller
+    "legend.fontsize": 'x-small',               # Make the legend/label fonts a little smaller
 
     "xtick.labelsize": 16,
 
@@ -450,7 +450,7 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp):
 
     "axes.labelsize": 16,                # LaTeX default is 10pt font.     "text.fontsize": 10,
 
-    "legend.fontsize": 12,               # Make the legend/label fonts a little smaller
+    "legend.fontsize": 'x-small',               # Make the legend/label fonts a little smaller
 
     "xtick.labelsize": 16,
 
@@ -513,7 +513,7 @@ def plot3(Ts, frequencies, modes, labels):
 
     "axes.labelsize": 16,                # LaTeX default is 10pt font.     "text.fontsize": 10,
 
-    "legend.fontsize": 12,               # Make the legend/label fonts a little smaller
+    "legend.fontsize": 'x-small',               # Make the legend/label fonts a little smaller
 
     "xtick.labelsize": 16,
 
@@ -569,7 +569,7 @@ def plot4(kk, frequencies, frequencies_disp, qpoints, x_labels):
 
     "axes.labelsize": 16,                # LaTeX default is 10pt font.     "text.fontsize": 10,
 
-    "legend.fontsize": 12,               # Make the legend/label fonts a little smaller
+    "legend.fontsize": 'x-small',               # Make the legend/label fonts a little smaller
 
     "xtick.labelsize": 16,
 
